# Changelog

## dev

- define user interface api

## 0.0.4

### ADD

- add x-s 、search_id signature
- add get note by id api
- add get self info api
- add get user info api
- add get home feed api
- add get note by keyword api
- add get user notes api

## 0.0.3

### ADD

- add pypi, doc, test ci actions

## 0.0.2

### ADD

- add Sphinx Doc

## 0.0.1

### ADD

- Structuring project (base on [Structuring Your Project](https://docs.python-guide.org/writing/structure/))
